//
//  LPBSBridge.h
//  IMLCoapBase
//
//  Created by 朱永利 on 2018/8/2.
//  Copyright © 2018年 ZhuYongli. All rights reserved.
//

#import <Foundation/Foundation.h>
#import "LPBSDiscovery.h"
#import "LPBSConnection.h"



extern NSString * kLpbsErrorDomian;

/**
 * Link protocol bridge 协议类， 每一个 protocol bridge 负责完成第三方通信协议跟
 * 阿里云 IoT 本地通信模块的桥接工作。Bridge中需要实现第三方设备的发现能力，第三方设备数据通信能力
 * 在开发者开发Bridge时，需要命名一个 LPBSBridgeImpl开头的类，如LPBSBridgeImplAlcs，该类需要
 * 实现 protocol LPBSBridge。Link protocol bridge system在初始化时会遍历所有这样的类，将这些类的实例
 * 加入到 Bridge管理队列中
 */
@protocol LPBSBridge <NSObject>

/**
 * bridge入口方法。
 * Link protocol bridge system 在发现LPBSBridgeImpl开头的类时，会调用该类的这个方法让Bridge模块
 * 去做初始化工作. 比如注册认证服务。参考 `LPBSAuthServiceManager`
 */
- (void)bridgeEntry;


/**
   bridge开发者给bridge命名的名字，此名字即为 bridge的唯一标识
 @return 适配者名字
 */
- (NSString *)getVendorName;



/**
 * 当前所适配的bridge支持哪些产品型号(private model)。
 * 这里的产品型号是设备的厂家私有产品型号，当ISV厂家在阿里云IoT后台注册产品时，IoT后台会给产品分配一个
 * IoT专属的产品型号（productKey）,同时需要输入产品的厂家私有型号(private model)。同时IoT后台会保存
 * private model 到 productKey的映射关系。
 @return 厂家私有产品型号列表,如果不清楚会支持哪些model，可以返回nil。
 */
- (NSArray<NSString *> *)supportModelList;


/**
 返回可用于本地发现第三方设备的类实例

 @return 发现类实例
 */
- (id<LPBSDiscovery>)getDiscoveryInst;



/**
 创建设备连接的实例

 @param deviceInfo 所发现的设备信息
 @return LPBSConnection实例，用来跟设备建立连接，发送业务请求，接收设备事件等
 */
- (id<LPBSConnection>)createConnection:(id<LPBSDiscoveryDevice>)deviceInfo;

@end
