//
//  LPBSDiscovery
//  IMLCoapBase
//
//  Created by 朱永利 on 2018/8/2.
//  Copyright © 2018年 ZhuYongli. All rights reserved.
//

#import <Foundation/Foundation.h>
#import "LPBSBridgeDefine.h"

typedef NS_ENUM (NSInteger, LPBSDataFormat){
    LPBSDataFormatUnknown = 0,///< 未知格式
    LPBSDataFormatIca = 1,///< ICA数据格式,阿里云IoT定义的设备业务数据格式
    LPBSDataFormatRawData = 2,///< 设备原生数据格式，即厂家自定义的业务数据格式
};

@protocol LPBSDiscoveryDevice  <NSObject>

/**
 厂家私有的产品型号，在IoT后台注册产品，生成IoT productKey时需要输入productModel。
 IoT后台会保存productKey跟productModel的一一映射关系
 如 美的冰箱，型号: BCD-320WGPZM。那么此api应该就是返回 @"BCD-320WGPZM"
 */
@property(nonatomic, copy) NSString * productModel;


/**
 厂家私有的设备id，可以是SN，或mac地址。在同一产品型号下唯一
 如某BLE设备，其采用 MAC地址‘AA:BB:CC:DD:99:00’作为自己的 设备id，那么此API应返回
 @"AA:BB:CC:DD:99:00"
 */
@property(nonatomic, copy) NSString * deviceId;


/**
 本地发现的设备 所对应的 bridge 标识，即 bridge开发者给bridge命名的名字
 vendorName用于不同bridge之间彼此识别. 请参考 LPBSBridge 协议中的 getVendorName 方法
 此二处的值应该是一样的
 */
@property(nonatomic, copy) NSString * vendorName;



/**
 设备是否需要借助APP的云端通道将设备数据上行到阿里云IoT云端
 第三方厂家设备需请将此property 设置为 YES
 */
@property(nonatomic, assign) BOOL isDataToCloud;

/**
 本地发现的设备 tsl数据，可选项
 第三方厂家设备请直接设置为 nil
 */
@property(nonatomic, copy, nullable) NSData * tslData;




/**
 本地发现的设备业务数据格式是何种格式，存在两种 dataFormat
 1. ALINK_FORMAT  阿里云IoT平台定义的数据封装格式
 2. CUSTOM_FORMAT 第三方私有的数据封装格式
 第三方厂家请直接设置为 @"CUSTOM_FORMAT"
 */
@property(nonatomic, copy) NSString * dataFormat;


/**
 设备额外信息,第三方厂家设备请直接设置为 nil
 */
@property(nonatomic, copy, nullable) NSDictionary * extraInfo;
@end


/**
 * Link protocol bridge  system中用于做第三方设备发现的类
 * 开发者在做 协议桥接的时候，需要实现第三方设备的发现协议
 */
@protocol LPBSDiscovery <NSObject>


/**
 开始发现第三方协议设备
 @param resultBlock 发现的设备通过这里返回给调用者
 */
- (void)startDiscovery:(LPBSArrayResultBlock)resultBlock;


/**
 停止发现
 */
- (void)stopDiscovery;




/**
 返回当前发现的设备列表
 @return 返回当前发现的设备列表
 */
- (NSArray<id<LPBSDiscoveryDevice>> *)discoverdDevices;
@end




